@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::YANICK;
 our $AUTHORITY = 'cpan:YANICK';
-$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.23.0';
+$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.24.0';
 # ABSTRACT: Be like Yanick when you build your dists
 
 # [TODO] add CONTRIBUTING file
@@ -50,7 +50,7 @@ sub configure {
 
     $self->add_plugins(
         qw/ 
-            ContributorsFromGit
+            Git::Contributors
             ContributorsFile
             Test::Compile
             CoalescePod
@@ -183,14 +183,14 @@ Dist::Zilla::PluginBundle::YANICK - Be like Yanick when you build your dists
 
 =head1 VERSION
 
-version 0.23.0
+version 0.24.0
 
 =head1 DESCRIPTION
 
 This is the plugin bundle that Yanick uses to release
 his distributions. It's roughly equivalent to
 
-    [ContributorsFromGit]
+    [Git::Contributors]
     [ContributorsFile]
 
     [Test::Compile]
